@@ -9,56 +9,70 @@ class DaewooTV1: public PIRKeysetMetaData
 {
 public:
   DaewooTV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class DaewooTV2: public PIRKeysetMetaData
 {
 public:
   DaewooTV2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class DaewooTV3: public PIRKeysetMetaData
 {
 public:
   DaewooTV3(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class DaewooTV4: public PIRKeysetMetaData
 {
 public:
   DaewooTV4(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class DaewooDVD1: public PIRKeysetMetaData
 {
 public:
   DaewooDVD1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class DaewooVCR1: public PIRKeysetMetaData
 {
 public:
   DaewooVCR1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class DaewooVCR2: public PIRKeysetMetaData
 {
 public:
   DaewooVCR2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // DAEWOO_H
