@@ -12,6 +12,7 @@ class QListWidgetItem;
 class PIRSelectKeysetForm;
 class PIRSelectDeviceForm;
 class PIRPanelSelectionForm;
+class PIRPreferencesForm;
 class PIRDocumentationForm;
 class PIRAboutForm;
 class PIRKeysetManager;
@@ -45,6 +46,9 @@ public:
 
   void stopRepeating();
 
+  void selectPanel(
+    int index);
+
   void managePanel(
     PIRPanelName name,
     int state);
@@ -67,6 +71,10 @@ public:
 
   void enableButtons();
 
+  // Preferences actions:
+  void useMainPanel();
+  void useAltMainPanel();
+
 signals:
   void buttonPressed(
     unsigned int keysetID,
@@ -88,6 +96,7 @@ private slots:
   void on_actionSelectKeyset_triggered();
   void on_actionSelect_Device_By_Name_triggered();
   void on_actionArrange_Button_Panels_triggered();
+  void on_actionPreferences_triggered();
   void on_actionAbout_triggered();
   void on_actionDocumentation_triggered();
 
@@ -107,6 +116,7 @@ private:
   PIRSelectKeysetForm *selectKeysetForm;
   PIRSelectDeviceForm *selectDeviceForm;
   PIRPanelSelectionForm *panelSelectionForm;
+  PIRPreferencesForm *preferencesForm;
   PIRDocumentationForm *documentationForm;
   PIRAboutForm *aboutForm;
 
